@@ -2,6 +2,10 @@ from pathlib import Path
 
 
 def create_dir(dir_name: str):
+    """
+    :param dir_name: create dir use dir name
+    :return: None
+    """
     Path(dir_name).mkdir(
         parents=True,
         exist_ok=True
@@ -9,4 +13,4 @@ def create_dir(dir_name: str):
 
 
 def create_template_dir():
-    create_dir("je_loading_test/template")
+    create_dir("je_load_density/template")
